]> git.wh0rd.org - dump.git/blobdiff - rmt/rmt.c
Due credit to Jörg Schilling for RMT extended protocol.
[dump.git] / rmt / rmt.c
index bde137dcd17b101e14d9094c920a135678ca857b..2af48e3e0cd7f8560c2946a1faeb449c5da66169 100644 (file)
--- a/rmt/rmt.c
+++ b/rmt/rmt.c
@@ -2,8 +2,8 @@
  *     Ported to Linux's Second Extended File System as part of the
  *     dump and restore backup suit
  *     Remy Card <card@Linux.EU.Org>, 1994-1997
*     Stelian Pop <pop@noos.fr>, 1999-2000
*     Stelian Pop <pop@noos.fr> - Alcôve <www.alcove.fr>, 2000
  */
 
 /*
@@ -41,7 +41,7 @@
 
 #ifndef lint
 static const char rcsid[] =
-       "$Id: rmt.c,v 1.15 2001/05/26 11:11:16 stelian Exp $";
+       "$Id: rmt.c,v 1.17 2002/04/12 13:02:16 stelian Exp $";
 #endif /* not linux */
 
 /*
@@ -80,6 +80,8 @@ FILE  *debug;
 
 /*
  * Support for Sun's extended RMT protocol
+ *     code originally written by Jörg Schilling <schilling@fokus.gmd.de>
+ *     and relicensed by his permission from GPL to BSD for use in dump.
  */
 #define RMTI_VERSION    -1
 #define RMT_VERSION 1
@@ -2,8 +2,8 @@
  *     dump and restore backup suit
  *     Remy Card <card@Linux.EU.Org>, 1994-1997
- *     Stelian Pop <pop@noos.fr>, 1999-2000
- *     Stelian Pop <pop@noos.fr> - Alcôve <www.alcove.fr>, 2000
+ *     Stelian Pop <stelian@popies.net>, 1999-2000
+ *     Stelian Pop <stelian@popies.net> - Alcôve <www.alcove.com>, 2000-2002
  */
 